@@ -18,32 +18,56 @@ URLENCODE = getattr(urllib, 'parse', urllib).urlencode
 URLOPEN = getattr(urllib, 'request', urllib).urlopen
 
 SERVICE_MAPPING = {
+    'api': 'apigateway',
+    'appconfig': 'systems-manager/appconfig',
+    'appstream': 'appstream2',
+    'budgets': 'billing/home?#/budgets',
+    'c9': 'cloud9',
+    'ce': 'cost-management',
     'cfn': 'cloudformation',
-    'ddb': 'dynamodb',
-    'ssm': 'systems-manager',
-    'stepfunctions': 'states',
-    'sfn': 'states',
-    'org': 'organizations',
-    'api': 'apigateway',
-    'api': 'apigateway',
     'cfnt': 'cloudfront',
-    'cw': 'cloudwatch',
-    'codecommit': 'codesuite/codecommit',
+    'chime': 'https://chime.aws.amazon.com',
+    'code': 'codesuite',
     'codebuild': 'codesuite/codebuild',
+    'codecommit': 'codesuite/codecommit',
     'codedeploy': 'codesuite/codedeploy',
     'codepipeline': 'codesuite/codepipeline',
-    'code': 'codesuite',
+    'codestar': 'codesuite/codestar',
+    'codeartifact': 'codesuite/codeartifact',
+    'cw': 'cloudwatch',
+    'ddb': 'dynamodb',
+    'documentdb': 'docdb',
+    'eb': 'elasticbeanstalk',
+    'ec': 'elasticache',
+    'es': 'elasticsearch',
+    'event': 'events',
+    'eventbridge': 'events',
+    'gd': 'guardduty',
+    'honey': 'honeycode',
+    'k8s': 'eks',
+    'l': 'lambda',
+    'lightsail': 'ls',
+    'logs-insights': 'https://{region}.console.{amazon_domain}/cloudwatch/home?region={region}#logsV2:logs-insights',
+    'logs': 'https://console.{amazon_domain}/cloudwatch/home?region={region}#logsV2:log-groups',
+    'mq': 'amazon-mq',
+    'org': 'organizations',
+    'orgs': 'organizations',
+    'qs': 'https://quicksight.aws.amazon.com',
     'r53': 'route53',
     'route': 'route53',
-    'lightsail': 'ls',
-    'eb': 'elasticbeanstalk',
     'sar': 'serverlessrepo',
+    'secret': 'secretsmanager',
+    'sfn': 'states',
     'sgw': 'storagegateway',
-    'wat': 'wellarchitected',
+    'snow': 'importexport',
+    'ssm': 'systems-manager',
     'sso': 'singlesignon',
+    'stepfunctions': 'states',
+    'sumerian': 'sumerianv2',
     'waf': 'wafv2',
-    'logs': 'https://console.{amazon_domain}/cloudwatch/home?region={region}#logsV2:log-groups',
-    'logs-insights': 'https://{region}.console.{amazon_domain}/cloudwatch/home?region={region}#logsV2:logs-insights',
+    'wat': 'wellarchitected',
+    'workdocs': 'zocalo',
+    'workmail': 'workmail/v2',
 }
 
 
